Language
========

.. automodule:: siotls.language

   .. autoclass:: siotls.language.TLSIO
      :members:
      :show-inheritance:

   .. autoclass:: siotls.language.MissingData
      :members:
      :show-inheritance:

   .. autoclass:: siotls.language.TLSBufferError
      :members:
      :show-inheritance:

   .. autoclass:: siotls.language.BufferOverflowError
      :members:
      :show-inheritance:

   .. autoclass:: siotls.language.TooMuchDataError
      :members:
      :show-inheritance:
